@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Mailer.py 12380 2020-06-29 10:46:46Z Andy $
+# $Id: Mailer.py 12815 2021-03-25 08:36:41Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Andy $ (Last)
+# $Author: Lavender $ (Last)
 # $Date: 2013-01-30 12:13:45 +0800$
-# $Revision: 12380 $
+# $Revision: 12815 $
 
 import os
 import re
@@ -56,6 +56,7 @@ from emencia.django.newsletter.models import ContactMailingStatus, Newsletter
 from html2text import html2text as html2text_orig
 
 from Theophrastus.cloud.models import ErrorMessage
+from Theophrastus.newsletter_extension.models import BlackContact
 from Theophrastus.cloud.service import CloudService
 from Theophrastus.Utility import getComment, trackLinks
 from Theophrastus.newsletter_extension.views import getHeaderContent, \
@@ -331,7 +332,7 @@ class CloudMailer(Mailer):
         resultMessage = ''
         newsletterId = self.newsletter.id
         contactId = contact.id
-
+        
         try:
             self.logger.info(
                 '[%d]_START: Send mail to contact<%d>.' %
@@ -342,7 +343,7 @@ class CloudMailer(Mailer):
             elif self.useCloud:
                 subject = self.build_title_content(contact)
                 replyTo = smart_str(self.newsletter.header_reply)
-
+                
                 contentHtml = self.buildEmailContent(contact)
 
                 result = self.smtp.sendMail(
@@ -442,7 +443,7 @@ class CloudMailer(Mailer):
         )
 
         return {'result': result , 'message': resultMessage, 'id': contactId}
-
+     
     def run(self):
         """
         Override.
